Documentation
¶
Index ¶
- Variables
- func RegisterV3PluginServer(s *grpc.Server, srv V3PluginServer)
- type Empty
- func (*Empty) Descriptor() ([]byte, []int)
- func (*Empty) ProtoMessage()
- func (m *Empty) Reset()
- func (m *Empty) String() string
- func (m *Empty) XXX_DiscardUnknown()
- func (m *Empty) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Empty) XXX_Merge(src proto.Message)
- func (m *Empty) XXX_Size() int
- func (m *Empty) XXX_Unmarshal(b []byte) error
- type HealthStatus
- type V3Bounds
- func (*V3Bounds) Descriptor() ([]byte, []int)
- func (m *V3Bounds) GetEnd() string
- func (m *V3Bounds) GetStart() string
- func (*V3Bounds) ProtoMessage()
- func (m *V3Bounds) Reset()
- func (m *V3Bounds) String() string
- func (m *V3Bounds) XXX_DiscardUnknown()
- func (m *V3Bounds) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3Bounds) XXX_Merge(src proto.Message)
- func (m *V3Bounds) XXX_Size() int
- func (m *V3Bounds) XXX_Unmarshal(b []byte) error
- type V3Device
- func (*V3Device) Descriptor() ([]byte, []int)
- func (m *V3Device) GetAlias() string
- func (m *V3Device) GetCapabilities() *V3DeviceCapability
- func (m *V3Device) GetId() string
- func (m *V3Device) GetInfo() string
- func (m *V3Device) GetMetadata() map[string]string
- func (m *V3Device) GetOutputs() []*V3DeviceOutput
- func (m *V3Device) GetPlugin() string
- func (m *V3Device) GetSortIndex() int32
- func (m *V3Device) GetTags() []*V3Tag
- func (m *V3Device) GetTimestamp() string
- func (m *V3Device) GetType() string
- func (*V3Device) ProtoMessage()
- func (m *V3Device) Reset()
- func (m *V3Device) String() string
- func (m *V3Device) XXX_DiscardUnknown()
- func (m *V3Device) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3Device) XXX_Merge(src proto.Message)
- func (m *V3Device) XXX_Size() int
- func (m *V3Device) XXX_Unmarshal(b []byte) error
- type V3DeviceCapability
- func (*V3DeviceCapability) Descriptor() ([]byte, []int)
- func (m *V3DeviceCapability) GetMode() string
- func (m *V3DeviceCapability) GetWrite() *V3WriteCapability
- func (*V3DeviceCapability) ProtoMessage()
- func (m *V3DeviceCapability) Reset()
- func (m *V3DeviceCapability) String() string
- func (m *V3DeviceCapability) XXX_DiscardUnknown()
- func (m *V3DeviceCapability) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3DeviceCapability) XXX_Merge(src proto.Message)
- func (m *V3DeviceCapability) XXX_Size() int
- func (m *V3DeviceCapability) XXX_Unmarshal(b []byte) error
- type V3DeviceOutput
- func (*V3DeviceOutput) Descriptor() ([]byte, []int)
- func (m *V3DeviceOutput) GetName() string
- func (m *V3DeviceOutput) GetPrecision() int32
- func (m *V3DeviceOutput) GetScalingFactor() float64
- func (m *V3DeviceOutput) GetType() string
- func (m *V3DeviceOutput) GetUnit() *V3OutputUnit
- func (*V3DeviceOutput) ProtoMessage()
- func (m *V3DeviceOutput) Reset()
- func (m *V3DeviceOutput) String() string
- func (m *V3DeviceOutput) XXX_DiscardUnknown()
- func (m *V3DeviceOutput) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3DeviceOutput) XXX_Merge(src proto.Message)
- func (m *V3DeviceOutput) XXX_Size() int
- func (m *V3DeviceOutput) XXX_Unmarshal(b []byte) error
- type V3DeviceSelector
- func (*V3DeviceSelector) Descriptor() ([]byte, []int)
- func (m *V3DeviceSelector) GetId() string
- func (m *V3DeviceSelector) GetTags() []*V3Tag
- func (*V3DeviceSelector) ProtoMessage()
- func (m *V3DeviceSelector) Reset()
- func (m *V3DeviceSelector) String() string
- func (m *V3DeviceSelector) XXX_DiscardUnknown()
- func (m *V3DeviceSelector) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3DeviceSelector) XXX_Merge(src proto.Message)
- func (m *V3DeviceSelector) XXX_Size() int
- func (m *V3DeviceSelector) XXX_Unmarshal(b []byte) error
- type V3Health
- func (*V3Health) Descriptor() ([]byte, []int)
- func (m *V3Health) GetChecks() []*V3HealthCheck
- func (m *V3Health) GetStatus() HealthStatus
- func (m *V3Health) GetTimestamp() string
- func (*V3Health) ProtoMessage()
- func (m *V3Health) Reset()
- func (m *V3Health) String() string
- func (m *V3Health) XXX_DiscardUnknown()
- func (m *V3Health) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3Health) XXX_Merge(src proto.Message)
- func (m *V3Health) XXX_Size() int
- func (m *V3Health) XXX_Unmarshal(b []byte) error
- type V3HealthCheck
- func (*V3HealthCheck) Descriptor() ([]byte, []int)
- func (m *V3HealthCheck) GetMessage() string
- func (m *V3HealthCheck) GetName() string
- func (m *V3HealthCheck) GetStatus() HealthStatus
- func (m *V3HealthCheck) GetTimestamp() string
- func (m *V3HealthCheck) GetType() string
- func (*V3HealthCheck) ProtoMessage()
- func (m *V3HealthCheck) Reset()
- func (m *V3HealthCheck) String() string
- func (m *V3HealthCheck) XXX_DiscardUnknown()
- func (m *V3HealthCheck) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3HealthCheck) XXX_Merge(src proto.Message)
- func (m *V3HealthCheck) XXX_Size() int
- func (m *V3HealthCheck) XXX_Unmarshal(b []byte) error
- type V3Metadata
- func (*V3Metadata) Descriptor() ([]byte, []int)
- func (m *V3Metadata) GetDescription() string
- func (m *V3Metadata) GetId() string
- func (m *V3Metadata) GetMaintainer() string
- func (m *V3Metadata) GetName() string
- func (m *V3Metadata) GetTag() string
- func (m *V3Metadata) GetVcs() string
- func (*V3Metadata) ProtoMessage()
- func (m *V3Metadata) Reset()
- func (m *V3Metadata) String() string
- func (m *V3Metadata) XXX_DiscardUnknown()
- func (m *V3Metadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3Metadata) XXX_Merge(src proto.Message)
- func (m *V3Metadata) XXX_Size() int
- func (m *V3Metadata) XXX_Unmarshal(b []byte) error
- type V3OutputUnit
- func (*V3OutputUnit) Descriptor() ([]byte, []int)
- func (m *V3OutputUnit) GetName() string
- func (m *V3OutputUnit) GetSymbol() string
- func (*V3OutputUnit) ProtoMessage()
- func (m *V3OutputUnit) Reset()
- func (m *V3OutputUnit) String() string
- func (m *V3OutputUnit) XXX_DiscardUnknown()
- func (m *V3OutputUnit) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3OutputUnit) XXX_Merge(src proto.Message)
- func (m *V3OutputUnit) XXX_Size() int
- func (m *V3OutputUnit) XXX_Unmarshal(b []byte) error
- type V3PluginClient
- type V3PluginServer
- type V3Plugin_DevicesClient
- type V3Plugin_DevicesServer
- type V3Plugin_ReadCacheClient
- type V3Plugin_ReadCacheServer
- type V3Plugin_ReadClient
- type V3Plugin_ReadServer
- type V3Plugin_ReadStreamClient
- type V3Plugin_ReadStreamServer
- type V3Plugin_TransactionsClient
- type V3Plugin_TransactionsServer
- type V3Plugin_WriteAsyncClient
- type V3Plugin_WriteAsyncServer
- type V3Plugin_WriteSyncClient
- type V3Plugin_WriteSyncServer
- type V3ReadRequest
- func (*V3ReadRequest) Descriptor() ([]byte, []int)
- func (m *V3ReadRequest) GetSelector() *V3DeviceSelector
- func (*V3ReadRequest) ProtoMessage()
- func (m *V3ReadRequest) Reset()
- func (m *V3ReadRequest) String() string
- func (m *V3ReadRequest) XXX_DiscardUnknown()
- func (m *V3ReadRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3ReadRequest) XXX_Merge(src proto.Message)
- func (m *V3ReadRequest) XXX_Size() int
- func (m *V3ReadRequest) XXX_Unmarshal(b []byte) error
- type V3Reading
- func (*V3Reading) Descriptor() ([]byte, []int)
- func (m *V3Reading) GetBoolValue() bool
- func (m *V3Reading) GetBytesValue() []byte
- func (m *V3Reading) GetContext() map[string]string
- func (m *V3Reading) GetDeviceInfo() string
- func (m *V3Reading) GetDeviceType() string
- func (m *V3Reading) GetFloat32Value() float32
- func (m *V3Reading) GetFloat64Value() float64
- func (m *V3Reading) GetId() string
- func (m *V3Reading) GetInt32Value() int32
- func (m *V3Reading) GetInt64Value() int64
- func (m *V3Reading) GetStringValue() string
- func (m *V3Reading) GetTimestamp() string
- func (m *V3Reading) GetType() string
- func (m *V3Reading) GetUint32Value() uint32
- func (m *V3Reading) GetUint64Value() uint64
- func (m *V3Reading) GetUnit() *V3OutputUnit
- func (m *V3Reading) GetValue() isV3Reading_Value
- func (*V3Reading) ProtoMessage()
- func (m *V3Reading) Reset()
- func (m *V3Reading) String() string
- func (m *V3Reading) XXX_DiscardUnknown()
- func (m *V3Reading) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3Reading) XXX_Merge(src proto.Message)
- func (*V3Reading) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, ...)
- func (m *V3Reading) XXX_Size() int
- func (m *V3Reading) XXX_Unmarshal(b []byte) error
- type V3Reading_BoolValue
- type V3Reading_BytesValue
- type V3Reading_Float32Value
- type V3Reading_Float64Value
- type V3Reading_Int32Value
- type V3Reading_Int64Value
- type V3Reading_StringValue
- type V3Reading_Uint32Value
- type V3Reading_Uint64Value
- type V3StreamRequest
- func (*V3StreamRequest) Descriptor() ([]byte, []int)
- func (m *V3StreamRequest) GetSelectors() []*V3DeviceSelector
- func (*V3StreamRequest) ProtoMessage()
- func (m *V3StreamRequest) Reset()
- func (m *V3StreamRequest) String() string
- func (m *V3StreamRequest) XXX_DiscardUnknown()
- func (m *V3StreamRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3StreamRequest) XXX_Merge(src proto.Message)
- func (m *V3StreamRequest) XXX_Size() int
- func (m *V3StreamRequest) XXX_Unmarshal(b []byte) error
- type V3Tag
- func (*V3Tag) Descriptor() ([]byte, []int)
- func (m *V3Tag) GetAnnotation() string
- func (m *V3Tag) GetLabel() string
- func (m *V3Tag) GetNamespace() string
- func (*V3Tag) ProtoMessage()
- func (m *V3Tag) Reset()
- func (m *V3Tag) String() string
- func (m *V3Tag) XXX_DiscardUnknown()
- func (m *V3Tag) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3Tag) XXX_Merge(src proto.Message)
- func (m *V3Tag) XXX_Size() int
- func (m *V3Tag) XXX_Unmarshal(b []byte) error
- type V3TestStatus
- func (*V3TestStatus) Descriptor() ([]byte, []int)
- func (m *V3TestStatus) GetOk() bool
- func (*V3TestStatus) ProtoMessage()
- func (m *V3TestStatus) Reset()
- func (m *V3TestStatus) String() string
- func (m *V3TestStatus) XXX_DiscardUnknown()
- func (m *V3TestStatus) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3TestStatus) XXX_Merge(src proto.Message)
- func (m *V3TestStatus) XXX_Size() int
- func (m *V3TestStatus) XXX_Unmarshal(b []byte) error
- type V3TransactionSelector
- func (*V3TransactionSelector) Descriptor() ([]byte, []int)
- func (m *V3TransactionSelector) GetId() string
- func (*V3TransactionSelector) ProtoMessage()
- func (m *V3TransactionSelector) Reset()
- func (m *V3TransactionSelector) String() string
- func (m *V3TransactionSelector) XXX_DiscardUnknown()
- func (m *V3TransactionSelector) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3TransactionSelector) XXX_Merge(src proto.Message)
- func (m *V3TransactionSelector) XXX_Size() int
- func (m *V3TransactionSelector) XXX_Unmarshal(b []byte) error
- type V3TransactionStatus
- func (*V3TransactionStatus) Descriptor() ([]byte, []int)
- func (m *V3TransactionStatus) GetContext() *V3WriteData
- func (m *V3TransactionStatus) GetCreated() string
- func (m *V3TransactionStatus) GetId() string
- func (m *V3TransactionStatus) GetMessage() string
- func (m *V3TransactionStatus) GetStatus() WriteStatus
- func (m *V3TransactionStatus) GetTimeout() string
- func (m *V3TransactionStatus) GetUpdated() string
- func (*V3TransactionStatus) ProtoMessage()
- func (m *V3TransactionStatus) Reset()
- func (m *V3TransactionStatus) String() string
- func (m *V3TransactionStatus) XXX_DiscardUnknown()
- func (m *V3TransactionStatus) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3TransactionStatus) XXX_Merge(src proto.Message)
- func (m *V3TransactionStatus) XXX_Size() int
- func (m *V3TransactionStatus) XXX_Unmarshal(b []byte) error
- type V3Version
- func (*V3Version) Descriptor() ([]byte, []int)
- func (m *V3Version) GetArch() string
- func (m *V3Version) GetBuildDate() string
- func (m *V3Version) GetGitCommit() string
- func (m *V3Version) GetGitTag() string
- func (m *V3Version) GetOs() string
- func (m *V3Version) GetPluginVersion() string
- func (m *V3Version) GetSdkVersion() string
- func (*V3Version) ProtoMessage()
- func (m *V3Version) Reset()
- func (m *V3Version) String() string
- func (m *V3Version) XXX_DiscardUnknown()
- func (m *V3Version) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3Version) XXX_Merge(src proto.Message)
- func (m *V3Version) XXX_Size() int
- func (m *V3Version) XXX_Unmarshal(b []byte) error
- type V3WriteCapability
- func (*V3WriteCapability) Descriptor() ([]byte, []int)
- func (m *V3WriteCapability) GetActions() []string
- func (*V3WriteCapability) ProtoMessage()
- func (m *V3WriteCapability) Reset()
- func (m *V3WriteCapability) String() string
- func (m *V3WriteCapability) XXX_DiscardUnknown()
- func (m *V3WriteCapability) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3WriteCapability) XXX_Merge(src proto.Message)
- func (m *V3WriteCapability) XXX_Size() int
- func (m *V3WriteCapability) XXX_Unmarshal(b []byte) error
- type V3WriteData
- func (*V3WriteData) Descriptor() ([]byte, []int)
- func (m *V3WriteData) GetAction() string
- func (m *V3WriteData) GetData() []byte
- func (m *V3WriteData) GetTransaction() string
- func (*V3WriteData) ProtoMessage()
- func (m *V3WriteData) Reset()
- func (m *V3WriteData) String() string
- func (m *V3WriteData) XXX_DiscardUnknown()
- func (m *V3WriteData) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3WriteData) XXX_Merge(src proto.Message)
- func (m *V3WriteData) XXX_Size() int
- func (m *V3WriteData) XXX_Unmarshal(b []byte) error
- type V3WritePayload
- func (*V3WritePayload) Descriptor() ([]byte, []int)
- func (m *V3WritePayload) GetData() []*V3WriteData
- func (m *V3WritePayload) GetSelector() *V3DeviceSelector
- func (*V3WritePayload) ProtoMessage()
- func (m *V3WritePayload) Reset()
- func (m *V3WritePayload) String() string
- func (m *V3WritePayload) XXX_DiscardUnknown()
- func (m *V3WritePayload) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3WritePayload) XXX_Merge(src proto.Message)
- func (m *V3WritePayload) XXX_Size() int
- func (m *V3WritePayload) XXX_Unmarshal(b []byte) error
- type V3WriteTransaction
- func (*V3WriteTransaction) Descriptor() ([]byte, []int)
- func (m *V3WriteTransaction) GetContext() *V3WriteData
- func (m *V3WriteTransaction) GetDevice() string
- func (m *V3WriteTransaction) GetId() string
- func (m *V3WriteTransaction) GetTimeout() string
- func (*V3WriteTransaction) ProtoMessage()
- func (m *V3WriteTransaction) Reset()
- func (m *V3WriteTransaction) String() string
- func (m *V3WriteTransaction) XXX_DiscardUnknown()
- func (m *V3WriteTransaction) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *V3WriteTransaction) XXX_Merge(src proto.Message)
- func (m *V3WriteTransaction) XXX_Size() int
- func (m *V3WriteTransaction) XXX_Unmarshal(b []byte) error
- type WriteStatus
Constants ¶
This section is empty.
Variables ¶
var HealthStatus_name = map[int32]string{
0: "UNKNOWN",
1: "OK",
2: "FAILING",
}
var HealthStatus_value = map[string]int32{
"UNKNOWN": 0,
"OK": 1,
"FAILING": 2,
}
var WriteStatus_name = map[int32]string{
0: "PENDING",
1: "WRITING",
3: "DONE",
4: "ERROR",
}
var WriteStatus_value = map[string]int32{
"PENDING": 0,
"WRITING": 1,
"DONE": 3,
"ERROR": 4,
}
Functions ¶
func RegisterV3PluginServer ¶
func RegisterV3PluginServer(s *grpc.Server, srv V3PluginServer)
Types ¶
type Empty ¶
type Empty struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Empty is an empty message (no fields) which is used for RPC routes which do not require any input for the request.
func (*Empty) Descriptor ¶
func (*Empty) ProtoMessage ¶
func (*Empty) ProtoMessage()
func (*Empty) XXX_DiscardUnknown ¶
func (m *Empty) XXX_DiscardUnknown()
func (*Empty) XXX_Marshal ¶
func (*Empty) XXX_Unmarshal ¶
type HealthStatus ¶
type HealthStatus int32
HealthStatus is the status of a health check.
const ( HealthStatus_UNKNOWN HealthStatus = 0 HealthStatus_OK HealthStatus = 1 HealthStatus_FAILING HealthStatus = 2 )
func (HealthStatus) EnumDescriptor ¶
func (HealthStatus) EnumDescriptor() ([]byte, []int)
func (HealthStatus) String ¶
func (x HealthStatus) String() string
type V3Bounds ¶
type V3Bounds struct {
// RFC3339 formatted timestamp specifying the beginning of the time bound. If
// left unspecified, the start is considered unbound.
Start string `protobuf:"bytes,1,opt,name=start" json:"start,omitempty"`
// RFC3339 formatted timestamp specifying the ending of the time bound. If
// left unspecified, the end is considered unbound.
End string `protobuf:"bytes,2,opt,name=end" json:"end,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3Bounds specifies time bounds in RFC3339 format.
func (*V3Bounds) Descriptor ¶
func (*V3Bounds) ProtoMessage ¶
func (*V3Bounds) ProtoMessage()
func (*V3Bounds) XXX_DiscardUnknown ¶
func (m *V3Bounds) XXX_DiscardUnknown()
func (*V3Bounds) XXX_Marshal ¶
func (*V3Bounds) XXX_Unmarshal ¶
type V3Device ¶
type V3Device struct {
// RFC3339 timestamp for when the device info was gathered.
Timestamp string `protobuf:"bytes,1,opt,name=timestamp" json:"timestamp,omitempty"`
// The globally unique ID for the device.
Id string `protobuf:"bytes,2,opt,name=id" json:"id,omitempty"`
// The type of device.
Type string `protobuf:"bytes,3,opt,name=type" json:"type,omitempty"`
// The id of the plugin that the device is managed by.
Plugin string `protobuf:"bytes,4,opt,name=plugin" json:"plugin,omitempty"`
// Additional information for the device.
Info string `protobuf:"bytes,5,opt,name=info" json:"info,omitempty"`
// A human-readable alias for the device.
Alias string `protobuf:"bytes,6,opt,name=alias" json:"alias,omitempty"`
// Any arbitrary metadata associated with the device.
Metadata map[string]string `` /* 136-byte string literal not displayed */
// The read/write capabilities of the device.
Capabilities *V3DeviceCapability `protobuf:"bytes,8,opt,name=capabilities" json:"capabilities,omitempty"`
// The tags that are associated with the device.
Tags []*V3Tag `protobuf:"bytes,9,rep,name=tags" json:"tags,omitempty"`
// The reading outputs that the device can generate on read.
Outputs []*V3DeviceOutput `protobuf:"bytes,10,rep,name=outputs" json:"outputs,omitempty"`
// A 1-based sort ordinal for the device. This will help determine where
// the device shows up in the scan.
SortIndex int32 `protobuf:"varint,11,opt,name=sortIndex" json:"sortIndex,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3Device contains all of the pertinent known data associated with a device.
func (*V3Device) Descriptor ¶
func (*V3Device) GetCapabilities ¶
func (m *V3Device) GetCapabilities() *V3DeviceCapability
func (*V3Device) GetMetadata ¶
func (*V3Device) GetOutputs ¶
func (m *V3Device) GetOutputs() []*V3DeviceOutput
func (*V3Device) GetSortIndex ¶
func (*V3Device) GetTimestamp ¶
func (*V3Device) ProtoMessage ¶
func (*V3Device) ProtoMessage()
func (*V3Device) XXX_DiscardUnknown ¶
func (m *V3Device) XXX_DiscardUnknown()
func (*V3Device) XXX_Marshal ¶
func (*V3Device) XXX_Unmarshal ¶
type V3DeviceCapability ¶
type V3DeviceCapability struct {
// The capability mode of the device ("r": read only, "w": write only, "rw": read/write)
Mode string `protobuf:"bytes,1,opt,name=mode" json:"mode,omitempty"`
// The write capabilities of the device.
Write *V3WriteCapability `protobuf:"bytes,2,opt,name=write" json:"write,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3DeviceCapability specifies the capabilities that a device exposes via Synse.
func (*V3DeviceCapability) Descriptor ¶
func (*V3DeviceCapability) Descriptor() ([]byte, []int)
func (*V3DeviceCapability) GetMode ¶
func (m *V3DeviceCapability) GetMode() string
func (*V3DeviceCapability) GetWrite ¶
func (m *V3DeviceCapability) GetWrite() *V3WriteCapability
func (*V3DeviceCapability) ProtoMessage ¶
func (*V3DeviceCapability) ProtoMessage()
func (*V3DeviceCapability) Reset ¶
func (m *V3DeviceCapability) Reset()
func (*V3DeviceCapability) String ¶
func (m *V3DeviceCapability) String() string
func (*V3DeviceCapability) XXX_DiscardUnknown ¶
func (m *V3DeviceCapability) XXX_DiscardUnknown()
func (*V3DeviceCapability) XXX_Marshal ¶
func (m *V3DeviceCapability) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3DeviceCapability) XXX_Merge ¶
func (dst *V3DeviceCapability) XXX_Merge(src proto.Message)
func (*V3DeviceCapability) XXX_Size ¶
func (m *V3DeviceCapability) XXX_Size() int
func (*V3DeviceCapability) XXX_Unmarshal ¶
func (m *V3DeviceCapability) XXX_Unmarshal(b []byte) error
type V3DeviceOutput ¶
type V3DeviceOutput struct {
// The name of the device output.
Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// The type of the output.
Type string `protobuf:"bytes,2,opt,name=type" json:"type,omitempty"`
// The decimal precision of the output. A precision of 0 (default) means no
// precision is applied.
Precision int32 `protobuf:"varint,3,opt,name=precision" json:"precision,omitempty"`
// The factor to multiply the reading result returned from the device. This can be
// positive, negative, whole, or decimal.
ScalingFactor float64 `protobuf:"fixed64,4,opt,name=scalingFactor" json:"scalingFactor,omitempty"`
// The unit of measure for the reading output.
Unit *V3OutputUnit `protobuf:"bytes,5,opt,name=unit" json:"unit,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3DeviceOutput specifies the output types for a device's reading(s).
func (*V3DeviceOutput) Descriptor ¶
func (*V3DeviceOutput) Descriptor() ([]byte, []int)
func (*V3DeviceOutput) GetName ¶
func (m *V3DeviceOutput) GetName() string
func (*V3DeviceOutput) GetPrecision ¶
func (m *V3DeviceOutput) GetPrecision() int32
func (*V3DeviceOutput) GetScalingFactor ¶
func (m *V3DeviceOutput) GetScalingFactor() float64
func (*V3DeviceOutput) GetType ¶
func (m *V3DeviceOutput) GetType() string
func (*V3DeviceOutput) GetUnit ¶
func (m *V3DeviceOutput) GetUnit() *V3OutputUnit
func (*V3DeviceOutput) ProtoMessage ¶
func (*V3DeviceOutput) ProtoMessage()
func (*V3DeviceOutput) Reset ¶
func (m *V3DeviceOutput) Reset()
func (*V3DeviceOutput) String ¶
func (m *V3DeviceOutput) String() string
func (*V3DeviceOutput) XXX_DiscardUnknown ¶
func (m *V3DeviceOutput) XXX_DiscardUnknown()
func (*V3DeviceOutput) XXX_Marshal ¶
func (m *V3DeviceOutput) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3DeviceOutput) XXX_Merge ¶
func (dst *V3DeviceOutput) XXX_Merge(src proto.Message)
func (*V3DeviceOutput) XXX_Size ¶
func (m *V3DeviceOutput) XXX_Size() int
func (*V3DeviceOutput) XXX_Unmarshal ¶
func (m *V3DeviceOutput) XXX_Unmarshal(b []byte) error
type V3DeviceSelector ¶
type V3DeviceSelector struct {
// The tags to use as selectors.
Tags []*V3Tag `protobuf:"bytes,1,rep,name=tags" json:"tags,omitempty"`
// The ID of the device. If this is set, tags will be ignored.
Id string `protobuf:"bytes,2,opt,name=id" json:"id,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3DeviceSelector specifies a selector to identify devices for various actions.
func (*V3DeviceSelector) Descriptor ¶
func (*V3DeviceSelector) Descriptor() ([]byte, []int)
func (*V3DeviceSelector) GetId ¶
func (m *V3DeviceSelector) GetId() string
func (*V3DeviceSelector) GetTags ¶
func (m *V3DeviceSelector) GetTags() []*V3Tag
func (*V3DeviceSelector) ProtoMessage ¶
func (*V3DeviceSelector) ProtoMessage()
func (*V3DeviceSelector) Reset ¶
func (m *V3DeviceSelector) Reset()
func (*V3DeviceSelector) String ¶
func (m *V3DeviceSelector) String() string
func (*V3DeviceSelector) XXX_DiscardUnknown ¶
func (m *V3DeviceSelector) XXX_DiscardUnknown()
func (*V3DeviceSelector) XXX_Marshal ¶
func (m *V3DeviceSelector) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3DeviceSelector) XXX_Merge ¶
func (dst *V3DeviceSelector) XXX_Merge(src proto.Message)
func (*V3DeviceSelector) XXX_Size ¶
func (m *V3DeviceSelector) XXX_Size() int
func (*V3DeviceSelector) XXX_Unmarshal ¶
func (m *V3DeviceSelector) XXX_Unmarshal(b []byte) error
type V3Health ¶
type V3Health struct {
// RFC3339 formatted timestamp of the time when the health was checked.
Timestamp string `protobuf:"bytes,1,opt,name=timestamp" json:"timestamp,omitempty"`
// The overall health status of a plugin.
Status HealthStatus `protobuf:"varint,2,opt,name=status,enum=synse.HealthStatus" json:"status,omitempty"`
// All of the health checks for a plugin.
Checks []*V3HealthCheck `protobuf:"bytes,3,rep,name=checks" json:"checks,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3Health is the health status for a plugin.
func (*V3Health) Descriptor ¶
func (*V3Health) GetChecks ¶
func (m *V3Health) GetChecks() []*V3HealthCheck
func (*V3Health) GetStatus ¶
func (m *V3Health) GetStatus() HealthStatus
func (*V3Health) GetTimestamp ¶
func (*V3Health) ProtoMessage ¶
func (*V3Health) ProtoMessage()
func (*V3Health) XXX_DiscardUnknown ¶
func (m *V3Health) XXX_DiscardUnknown()
func (*V3Health) XXX_Marshal ¶
func (*V3Health) XXX_Unmarshal ¶
type V3HealthCheck ¶
type V3HealthCheck struct {
// The name of the health check.
Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// The status of the health check.
Status HealthStatus `protobuf:"varint,2,opt,name=status,enum=synse.HealthStatus" json:"status,omitempty"`
// Any additional information associated with the health check.
Message string `protobuf:"bytes,3,opt,name=message" json:"message,omitempty"`
// RFC3339 formatted timestamp at which the check was last completed.
Timestamp string `protobuf:"bytes,4,opt,name=timestamp" json:"timestamp,omitempty"`
// The type of health check. The different kinds of health check are
// defined in the SDK.
Type string `protobuf:"bytes,5,opt,name=type" json:"type,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3HealthCheck is the health check status for a plugin.
func (*V3HealthCheck) Descriptor ¶
func (*V3HealthCheck) Descriptor() ([]byte, []int)
func (*V3HealthCheck) GetMessage ¶
func (m *V3HealthCheck) GetMessage() string
func (*V3HealthCheck) GetName ¶
func (m *V3HealthCheck) GetName() string
func (*V3HealthCheck) GetStatus ¶
func (m *V3HealthCheck) GetStatus() HealthStatus
func (*V3HealthCheck) GetTimestamp ¶
func (m *V3HealthCheck) GetTimestamp() string
func (*V3HealthCheck) GetType ¶
func (m *V3HealthCheck) GetType() string
func (*V3HealthCheck) ProtoMessage ¶
func (*V3HealthCheck) ProtoMessage()
func (*V3HealthCheck) Reset ¶
func (m *V3HealthCheck) Reset()
func (*V3HealthCheck) String ¶
func (m *V3HealthCheck) String() string
func (*V3HealthCheck) XXX_DiscardUnknown ¶
func (m *V3HealthCheck) XXX_DiscardUnknown()
func (*V3HealthCheck) XXX_Marshal ¶
func (m *V3HealthCheck) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3HealthCheck) XXX_Merge ¶
func (dst *V3HealthCheck) XXX_Merge(src proto.Message)
func (*V3HealthCheck) XXX_Size ¶
func (m *V3HealthCheck) XXX_Size() int
func (*V3HealthCheck) XXX_Unmarshal ¶
func (m *V3HealthCheck) XXX_Unmarshal(b []byte) error
type V3Metadata ¶
type V3Metadata struct {
// The name of the plugin.
Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// The maintainer of the plugin.
Maintainer string `protobuf:"bytes,2,opt,name=maintainer" json:"maintainer,omitempty"`
// The normalized tag name for plugin meta-info.
Tag string `protobuf:"bytes,3,opt,name=tag" json:"tag,omitempty"`
// A brief description of the plugin.
Description string `protobuf:"bytes,4,opt,name=description" json:"description,omitempty"`
// A link to the plugin's VCS repo.
Vcs string `protobuf:"bytes,5,opt,name=vcs" json:"vcs,omitempty"`
// The generated plugin namespace ID.
Id string `protobuf:"bytes,6,opt,name=id" json:"id,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3Metadata is static metadata about a plugin.
func (*V3Metadata) Descriptor ¶
func (*V3Metadata) Descriptor() ([]byte, []int)
func (*V3Metadata) GetDescription ¶
func (m *V3Metadata) GetDescription() string
func (*V3Metadata) GetId ¶
func (m *V3Metadata) GetId() string
func (*V3Metadata) GetMaintainer ¶
func (m *V3Metadata) GetMaintainer() string
func (*V3Metadata) GetName ¶
func (m *V3Metadata) GetName() string
func (*V3Metadata) GetTag ¶
func (m *V3Metadata) GetTag() string
func (*V3Metadata) GetVcs ¶
func (m *V3Metadata) GetVcs() string
func (*V3Metadata) ProtoMessage ¶
func (*V3Metadata) ProtoMessage()
func (*V3Metadata) Reset ¶
func (m *V3Metadata) Reset()
func (*V3Metadata) String ¶
func (m *V3Metadata) String() string
func (*V3Metadata) XXX_DiscardUnknown ¶
func (m *V3Metadata) XXX_DiscardUnknown()
func (*V3Metadata) XXX_Marshal ¶
func (m *V3Metadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3Metadata) XXX_Merge ¶
func (dst *V3Metadata) XXX_Merge(src proto.Message)
func (*V3Metadata) XXX_Size ¶
func (m *V3Metadata) XXX_Size() int
func (*V3Metadata) XXX_Unmarshal ¶
func (m *V3Metadata) XXX_Unmarshal(b []byte) error
type V3OutputUnit ¶
type V3OutputUnit struct {
// The full name of the unit.
Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// The symbolic representation of the unit.
Symbol string `protobuf:"bytes,2,opt,name=symbol" json:"symbol,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3OutputUnit the unit of measure for a reading.
func (*V3OutputUnit) Descriptor ¶
func (*V3OutputUnit) Descriptor() ([]byte, []int)
func (*V3OutputUnit) GetName ¶
func (m *V3OutputUnit) GetName() string
func (*V3OutputUnit) GetSymbol ¶
func (m *V3OutputUnit) GetSymbol() string
func (*V3OutputUnit) ProtoMessage ¶
func (*V3OutputUnit) ProtoMessage()
func (*V3OutputUnit) Reset ¶
func (m *V3OutputUnit) Reset()
func (*V3OutputUnit) String ¶
func (m *V3OutputUnit) String() string
func (*V3OutputUnit) XXX_DiscardUnknown ¶
func (m *V3OutputUnit) XXX_DiscardUnknown()
func (*V3OutputUnit) XXX_Marshal ¶
func (m *V3OutputUnit) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3OutputUnit) XXX_Merge ¶
func (dst *V3OutputUnit) XXX_Merge(src proto.Message)
func (*V3OutputUnit) XXX_Size ¶
func (m *V3OutputUnit) XXX_Size() int
func (*V3OutputUnit) XXX_Unmarshal ¶
func (m *V3OutputUnit) XXX_Unmarshal(b []byte) error
type V3PluginClient ¶
type V3PluginClient interface {
// Devices gets all devices that a plugin manages.
Devices(ctx context.Context, in *V3DeviceSelector, opts ...grpc.CallOption) (V3Plugin_DevicesClient, error)
// Health gets the health status of a plugin.
Health(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*V3Health, error)
// Metadata gets the plugin meta-information.
Metadata(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*V3Metadata, error)
// Read gets readings from the specified plugin device(s).
Read(ctx context.Context, in *V3ReadRequest, opts ...grpc.CallOption) (V3Plugin_ReadClient, error)
// ReadCache gets the cached readings from the plugin. If the plugin
// is not configured to cache readings, it will returned the entire
// current read state.
ReadCache(ctx context.Context, in *V3Bounds, opts ...grpc.CallOption) (V3Plugin_ReadCacheClient, error)
// ReadStream returns reading data for the specified devices as they
// are read by the plugin.
ReadStream(ctx context.Context, in *V3StreamRequest, opts ...grpc.CallOption) (V3Plugin_ReadStreamClient, error)
// Test checks whether the plugin is reachable and ready.
Test(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*V3TestStatus, error)
// Transaction gets the status of a write transaction for an
// asynchronous write.
Transaction(ctx context.Context, in *V3TransactionSelector, opts ...grpc.CallOption) (*V3TransactionStatus, error)
// Transactions gets all transactions which are currently kept
// in the plugin's transaction cache.
Transactions(ctx context.Context, in *Empty, opts ...grpc.CallOption) (V3Plugin_TransactionsClient, error)
// Version gets the version information for the plugin.
Version(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*V3Version, error)
// WriteAsync writes data to the specified plugin device. A transaction ID
// is returned so the write status can be checked asynchronously.
WriteAsync(ctx context.Context, in *V3WritePayload, opts ...grpc.CallOption) (V3Plugin_WriteAsyncClient, error)
// WriteSync writes data to the specified plugin device. The request blocks
// until the write resolves so no asynchronous checking is required.
WriteSync(ctx context.Context, in *V3WritePayload, opts ...grpc.CallOption) (V3Plugin_WriteSyncClient, error)
}
func NewV3PluginClient ¶
func NewV3PluginClient(cc *grpc.ClientConn) V3PluginClient
type V3PluginServer ¶
type V3PluginServer interface {
// Devices gets all devices that a plugin manages.
Devices(*V3DeviceSelector, V3Plugin_DevicesServer) error
// Health gets the health status of a plugin.
Health(context.Context, *Empty) (*V3Health, error)
// Metadata gets the plugin meta-information.
Metadata(context.Context, *Empty) (*V3Metadata, error)
// Read gets readings from the specified plugin device(s).
Read(*V3ReadRequest, V3Plugin_ReadServer) error
// ReadCache gets the cached readings from the plugin. If the plugin
// is not configured to cache readings, it will returned the entire
// current read state.
ReadCache(*V3Bounds, V3Plugin_ReadCacheServer) error
// ReadStream returns reading data for the specified devices as they
// are read by the plugin.
ReadStream(*V3StreamRequest, V3Plugin_ReadStreamServer) error
// Test checks whether the plugin is reachable and ready.
Test(context.Context, *Empty) (*V3TestStatus, error)
// Transaction gets the status of a write transaction for an
// asynchronous write.
Transaction(context.Context, *V3TransactionSelector) (*V3TransactionStatus, error)
// Transactions gets all transactions which are currently kept
// in the plugin's transaction cache.
Transactions(*Empty, V3Plugin_TransactionsServer) error
// Version gets the version information for the plugin.
Version(context.Context, *Empty) (*V3Version, error)
// WriteAsync writes data to the specified plugin device. A transaction ID
// is returned so the write status can be checked asynchronously.
WriteAsync(*V3WritePayload, V3Plugin_WriteAsyncServer) error
// WriteSync writes data to the specified plugin device. The request blocks
// until the write resolves so no asynchronous checking is required.
WriteSync(*V3WritePayload, V3Plugin_WriteSyncServer) error
}
type V3Plugin_DevicesClient ¶
type V3Plugin_DevicesClient interface {
Recv() (*V3Device, error)
grpc.ClientStream
}
type V3Plugin_DevicesServer ¶
type V3Plugin_DevicesServer interface {
Send(*V3Device) error
grpc.ServerStream
}
type V3Plugin_ReadCacheClient ¶
type V3Plugin_ReadCacheClient interface {
Recv() (*V3Reading, error)
grpc.ClientStream
}
type V3Plugin_ReadCacheServer ¶
type V3Plugin_ReadCacheServer interface {
Send(*V3Reading) error
grpc.ServerStream
}
type V3Plugin_ReadClient ¶
type V3Plugin_ReadClient interface {
Recv() (*V3Reading, error)
grpc.ClientStream
}
type V3Plugin_ReadServer ¶
type V3Plugin_ReadServer interface {
Send(*V3Reading) error
grpc.ServerStream
}
type V3Plugin_ReadStreamClient ¶
type V3Plugin_ReadStreamClient interface {
Recv() (*V3Reading, error)
grpc.ClientStream
}
type V3Plugin_ReadStreamServer ¶
type V3Plugin_ReadStreamServer interface {
Send(*V3Reading) error
grpc.ServerStream
}
type V3Plugin_TransactionsClient ¶
type V3Plugin_TransactionsClient interface {
Recv() (*V3TransactionStatus, error)
grpc.ClientStream
}
type V3Plugin_TransactionsServer ¶
type V3Plugin_TransactionsServer interface {
Send(*V3TransactionStatus) error
grpc.ServerStream
}
type V3Plugin_WriteAsyncClient ¶
type V3Plugin_WriteAsyncClient interface {
Recv() (*V3WriteTransaction, error)
grpc.ClientStream
}
type V3Plugin_WriteAsyncServer ¶
type V3Plugin_WriteAsyncServer interface {
Send(*V3WriteTransaction) error
grpc.ServerStream
}
type V3Plugin_WriteSyncClient ¶
type V3Plugin_WriteSyncClient interface {
Recv() (*V3TransactionStatus, error)
grpc.ClientStream
}
type V3Plugin_WriteSyncServer ¶
type V3Plugin_WriteSyncServer interface {
Send(*V3TransactionStatus) error
grpc.ServerStream
}
type V3ReadRequest ¶
type V3ReadRequest struct {
// The selector for the device(s) to read from.
Selector *V3DeviceSelector `protobuf:"bytes,1,opt,name=selector" json:"selector,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3ReadRequest is a request for device readings.
func (*V3ReadRequest) Descriptor ¶
func (*V3ReadRequest) Descriptor() ([]byte, []int)
func (*V3ReadRequest) GetSelector ¶
func (m *V3ReadRequest) GetSelector() *V3DeviceSelector
func (*V3ReadRequest) ProtoMessage ¶
func (*V3ReadRequest) ProtoMessage()
func (*V3ReadRequest) Reset ¶
func (m *V3ReadRequest) Reset()
func (*V3ReadRequest) String ¶
func (m *V3ReadRequest) String() string
func (*V3ReadRequest) XXX_DiscardUnknown ¶
func (m *V3ReadRequest) XXX_DiscardUnknown()
func (*V3ReadRequest) XXX_Marshal ¶
func (m *V3ReadRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3ReadRequest) XXX_Merge ¶
func (dst *V3ReadRequest) XXX_Merge(src proto.Message)
func (*V3ReadRequest) XXX_Size ¶
func (m *V3ReadRequest) XXX_Size() int
func (*V3ReadRequest) XXX_Unmarshal ¶
func (m *V3ReadRequest) XXX_Unmarshal(b []byte) error
type V3Reading ¶
type V3Reading struct {
// The GUID of the device being read from.
Id string `protobuf:"bytes,1,opt,name=id" json:"id,omitempty"`
// RFC3339 formatted timestamp for when the reading was taken.
Timestamp string `protobuf:"bytes,2,opt,name=timestamp" json:"timestamp,omitempty"`
// The type of the reading.
Type string `protobuf:"bytes,3,opt,name=type" json:"type,omitempty"`
// The type of the device the reading originated from.
DeviceType string `protobuf:"bytes,4,opt,name=deviceType" json:"deviceType,omitempty"`
// Any additional information associated with a reading.
Context map[string]string `` /* 134-byte string literal not displayed */
// The unit of measure for the reading.
Unit *V3OutputUnit `protobuf:"bytes,6,opt,name=unit" json:"unit,omitempty"`
// The value of the reading.
//
// Types that are valid to be assigned to Value:
// *V3Reading_StringValue
// *V3Reading_BoolValue
// *V3Reading_Float32Value
// *V3Reading_Float64Value
// *V3Reading_Int32Value
// *V3Reading_Int64Value
// *V3Reading_BytesValue
// *V3Reading_Uint32Value
// *V3Reading_Uint64Value
Value isV3Reading_Value `protobuf_oneof:"value"`
// Info string associated with the Reading's device. This provides
// additional human-readable context for the reading.
DeviceInfo string `protobuf:"bytes,16,opt,name=deviceInfo" json:"deviceInfo,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3Reading is a reading response from a device.
func (*V3Reading) Descriptor ¶
func (*V3Reading) GetBoolValue ¶
func (*V3Reading) GetBytesValue ¶
func (*V3Reading) GetContext ¶
func (*V3Reading) GetDeviceInfo ¶
func (*V3Reading) GetDeviceType ¶
func (*V3Reading) GetFloat32Value ¶
func (*V3Reading) GetFloat64Value ¶
func (*V3Reading) GetInt32Value ¶
func (*V3Reading) GetInt64Value ¶
func (*V3Reading) GetStringValue ¶
func (*V3Reading) GetTimestamp ¶
func (*V3Reading) GetUint32Value ¶
func (*V3Reading) GetUint64Value ¶
func (*V3Reading) GetUnit ¶
func (m *V3Reading) GetUnit() *V3OutputUnit
func (*V3Reading) ProtoMessage ¶
func (*V3Reading) ProtoMessage()
func (*V3Reading) XXX_DiscardUnknown ¶
func (m *V3Reading) XXX_DiscardUnknown()
func (*V3Reading) XXX_Marshal ¶
func (*V3Reading) XXX_OneofFuncs ¶
func (*V3Reading) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{})
XXX_OneofFuncs is for the internal use of the proto package.
func (*V3Reading) XXX_Unmarshal ¶
type V3Reading_BoolValue ¶
type V3Reading_BoolValue struct {
BoolValue bool `protobuf:"varint,8,opt,name=bool_value,json=boolValue,oneof"`
}
type V3Reading_BytesValue ¶
type V3Reading_BytesValue struct {
BytesValue []byte `protobuf:"bytes,13,opt,name=bytes_value,json=bytesValue,proto3,oneof"`
}
type V3Reading_Float32Value ¶
type V3Reading_Float32Value struct {
Float32Value float32 `protobuf:"fixed32,9,opt,name=float32_value,json=float32Value,oneof"`
}
type V3Reading_Float64Value ¶
type V3Reading_Float64Value struct {
Float64Value float64 `protobuf:"fixed64,10,opt,name=float64_value,json=float64Value,oneof"`
}
type V3Reading_Int32Value ¶
type V3Reading_Int32Value struct {
Int32Value int32 `protobuf:"varint,11,opt,name=int32_value,json=int32Value,oneof"`
}
type V3Reading_Int64Value ¶
type V3Reading_Int64Value struct {
Int64Value int64 `protobuf:"varint,12,opt,name=int64_value,json=int64Value,oneof"`
}
type V3Reading_StringValue ¶
type V3Reading_StringValue struct {
StringValue string `protobuf:"bytes,7,opt,name=string_value,json=stringValue,oneof"`
}
type V3Reading_Uint32Value ¶
type V3Reading_Uint32Value struct {
Uint32Value uint32 `protobuf:"varint,14,opt,name=uint32_value,json=uint32Value,oneof"`
}
type V3Reading_Uint64Value ¶
type V3Reading_Uint64Value struct {
Uint64Value uint64 `protobuf:"varint,15,opt,name=uint64_value,json=uint64Value,oneof"`
}
type V3StreamRequest ¶
type V3StreamRequest struct {
Selectors []*V3DeviceSelector `protobuf:"bytes,1,rep,name=selectors" json:"selectors,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3StreamRequest is a request to stream device readings. It allows the requester to specify multiple device selectors to allow for additive device selection.
func (*V3StreamRequest) Descriptor ¶
func (*V3StreamRequest) Descriptor() ([]byte, []int)
func (*V3StreamRequest) GetSelectors ¶
func (m *V3StreamRequest) GetSelectors() []*V3DeviceSelector
func (*V3StreamRequest) ProtoMessage ¶
func (*V3StreamRequest) ProtoMessage()
func (*V3StreamRequest) Reset ¶
func (m *V3StreamRequest) Reset()
func (*V3StreamRequest) String ¶
func (m *V3StreamRequest) String() string
func (*V3StreamRequest) XXX_DiscardUnknown ¶
func (m *V3StreamRequest) XXX_DiscardUnknown()
func (*V3StreamRequest) XXX_Marshal ¶
func (m *V3StreamRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3StreamRequest) XXX_Merge ¶
func (dst *V3StreamRequest) XXX_Merge(src proto.Message)
func (*V3StreamRequest) XXX_Size ¶
func (m *V3StreamRequest) XXX_Size() int
func (*V3StreamRequest) XXX_Unmarshal ¶
func (m *V3StreamRequest) XXX_Unmarshal(b []byte) error
type V3Tag ¶
type V3Tag struct {
// The namespace of the tag.
Namespace string `protobuf:"bytes,1,opt,name=namespace" json:"namespace,omitempty"`
// The annotation of the tag.
Annotation string `protobuf:"bytes,2,opt,name=annotation" json:"annotation,omitempty"`
// The tag label.
Label string `protobuf:"bytes,3,opt,name=label" json:"label,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3Tag is a specification for a single tag.
func (*V3Tag) Descriptor ¶
func (*V3Tag) GetAnnotation ¶
func (*V3Tag) GetNamespace ¶
func (*V3Tag) ProtoMessage ¶
func (*V3Tag) ProtoMessage()
func (*V3Tag) XXX_DiscardUnknown ¶
func (m *V3Tag) XXX_DiscardUnknown()
func (*V3Tag) XXX_Marshal ¶
func (*V3Tag) XXX_Unmarshal ¶
type V3TestStatus ¶
type V3TestStatus struct {
// A flag describing whether the plugin is ready and reachable.
Ok bool `protobuf:"varint,1,opt,name=ok" json:"ok,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3TestStatus is the status response for plugin availability.
func (*V3TestStatus) Descriptor ¶
func (*V3TestStatus) Descriptor() ([]byte, []int)
func (*V3TestStatus) GetOk ¶
func (m *V3TestStatus) GetOk() bool
func (*V3TestStatus) ProtoMessage ¶
func (*V3TestStatus) ProtoMessage()
func (*V3TestStatus) Reset ¶
func (m *V3TestStatus) Reset()
func (*V3TestStatus) String ¶
func (m *V3TestStatus) String() string
func (*V3TestStatus) XXX_DiscardUnknown ¶
func (m *V3TestStatus) XXX_DiscardUnknown()
func (*V3TestStatus) XXX_Marshal ¶
func (m *V3TestStatus) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3TestStatus) XXX_Merge ¶
func (dst *V3TestStatus) XXX_Merge(src proto.Message)
func (*V3TestStatus) XXX_Size ¶
func (m *V3TestStatus) XXX_Size() int
func (*V3TestStatus) XXX_Unmarshal ¶
func (m *V3TestStatus) XXX_Unmarshal(b []byte) error
type V3TransactionSelector ¶
type V3TransactionSelector struct {
// The ID of a write transaction.
Id string `protobuf:"bytes,1,opt,name=id" json:"id,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3TransactionSelector specifies a selector to identify a transaction.
func (*V3TransactionSelector) Descriptor ¶
func (*V3TransactionSelector) Descriptor() ([]byte, []int)
func (*V3TransactionSelector) GetId ¶
func (m *V3TransactionSelector) GetId() string
func (*V3TransactionSelector) ProtoMessage ¶
func (*V3TransactionSelector) ProtoMessage()
func (*V3TransactionSelector) Reset ¶
func (m *V3TransactionSelector) Reset()
func (*V3TransactionSelector) String ¶
func (m *V3TransactionSelector) String() string
func (*V3TransactionSelector) XXX_DiscardUnknown ¶
func (m *V3TransactionSelector) XXX_DiscardUnknown()
func (*V3TransactionSelector) XXX_Marshal ¶
func (m *V3TransactionSelector) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3TransactionSelector) XXX_Merge ¶
func (dst *V3TransactionSelector) XXX_Merge(src proto.Message)
func (*V3TransactionSelector) XXX_Size ¶
func (m *V3TransactionSelector) XXX_Size() int
func (*V3TransactionSelector) XXX_Unmarshal ¶
func (m *V3TransactionSelector) XXX_Unmarshal(b []byte) error
type V3TransactionStatus ¶
type V3TransactionStatus struct {
// The ID of the write transaction.
Id string `protobuf:"bytes,1,opt,name=id" json:"id,omitempty"`
// RFC3339 formatted timestamp of when the transaction was created.
Created string `protobuf:"bytes,2,opt,name=created" json:"created,omitempty"`
// RFC3339 formatted timestamp of when the transaction was last updated.
Updated string `protobuf:"bytes,3,opt,name=updated" json:"updated,omitempty"`
// Context information for any errors that may have occurred.
Message string `protobuf:"bytes,4,opt,name=message" json:"message,omitempty"`
// The timeout within which the transaction remains valid.
Timeout string `protobuf:"bytes,5,opt,name=timeout" json:"timeout,omitempty"`
// The status of the write (pending, writing, done, error).
Status WriteStatus `protobuf:"varint,6,opt,name=status,enum=synse.WriteStatus" json:"status,omitempty"`
// The data that was written for the write transaction.
Context *V3WriteData `protobuf:"bytes,7,opt,name=context" json:"context,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3TransactionStatus the status of a write transaction.
func (*V3TransactionStatus) Descriptor ¶
func (*V3TransactionStatus) Descriptor() ([]byte, []int)
func (*V3TransactionStatus) GetContext ¶
func (m *V3TransactionStatus) GetContext() *V3WriteData
func (*V3TransactionStatus) GetCreated ¶
func (m *V3TransactionStatus) GetCreated() string
func (*V3TransactionStatus) GetId ¶
func (m *V3TransactionStatus) GetId() string
func (*V3TransactionStatus) GetMessage ¶
func (m *V3TransactionStatus) GetMessage() string
func (*V3TransactionStatus) GetStatus ¶
func (m *V3TransactionStatus) GetStatus() WriteStatus
func (*V3TransactionStatus) GetTimeout ¶
func (m *V3TransactionStatus) GetTimeout() string
func (*V3TransactionStatus) GetUpdated ¶
func (m *V3TransactionStatus) GetUpdated() string
func (*V3TransactionStatus) ProtoMessage ¶
func (*V3TransactionStatus) ProtoMessage()
func (*V3TransactionStatus) Reset ¶
func (m *V3TransactionStatus) Reset()
func (*V3TransactionStatus) String ¶
func (m *V3TransactionStatus) String() string
func (*V3TransactionStatus) XXX_DiscardUnknown ¶
func (m *V3TransactionStatus) XXX_DiscardUnknown()
func (*V3TransactionStatus) XXX_Marshal ¶
func (m *V3TransactionStatus) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3TransactionStatus) XXX_Merge ¶
func (dst *V3TransactionStatus) XXX_Merge(src proto.Message)
func (*V3TransactionStatus) XXX_Size ¶
func (m *V3TransactionStatus) XXX_Size() int
func (*V3TransactionStatus) XXX_Unmarshal ¶
func (m *V3TransactionStatus) XXX_Unmarshal(b []byte) error
type V3Version ¶
type V3Version struct {
// The semantic version of the plugin.
PluginVersion string `protobuf:"bytes,1,opt,name=pluginVersion" json:"pluginVersion,omitempty"`
// The version of the SDK the plugin uses.
SdkVersion string `protobuf:"bytes,2,opt,name=sdkVersion" json:"sdkVersion,omitempty"`
// The timestamp from when the plugin was built.
BuildDate string `protobuf:"bytes,3,opt,name=buildDate" json:"buildDate,omitempty"`
// The commit hash at which the plugin was built.
GitCommit string `protobuf:"bytes,4,opt,name=gitCommit" json:"gitCommit,omitempty"`
// The tag name at which the plugin was built.
GitTag string `protobuf:"bytes,5,opt,name=gitTag" json:"gitTag,omitempty"`
// The architecture that the plugin was built.
Arch string `protobuf:"bytes,6,opt,name=arch" json:"arch,omitempty"`
// The operating system that the plugin was built for.
Os string `protobuf:"bytes,7,opt,name=os" json:"os,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3Version provides version information for the plugin.
func (*V3Version) Descriptor ¶
func (*V3Version) GetBuildDate ¶
func (*V3Version) GetGitCommit ¶
func (*V3Version) GetPluginVersion ¶
func (*V3Version) GetSdkVersion ¶
func (*V3Version) ProtoMessage ¶
func (*V3Version) ProtoMessage()
func (*V3Version) XXX_DiscardUnknown ¶
func (m *V3Version) XXX_DiscardUnknown()
func (*V3Version) XXX_Marshal ¶
func (*V3Version) XXX_Unmarshal ¶
type V3WriteCapability ¶
type V3WriteCapability struct {
// The write actions supported by a device.
Actions []string `protobuf:"bytes,1,rep,name=actions" json:"actions,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3WriteCapability specifies the write capabilities for a device.
func (*V3WriteCapability) Descriptor ¶
func (*V3WriteCapability) Descriptor() ([]byte, []int)
func (*V3WriteCapability) GetActions ¶
func (m *V3WriteCapability) GetActions() []string
func (*V3WriteCapability) ProtoMessage ¶
func (*V3WriteCapability) ProtoMessage()
func (*V3WriteCapability) Reset ¶
func (m *V3WriteCapability) Reset()
func (*V3WriteCapability) String ¶
func (m *V3WriteCapability) String() string
func (*V3WriteCapability) XXX_DiscardUnknown ¶
func (m *V3WriteCapability) XXX_DiscardUnknown()
func (*V3WriteCapability) XXX_Marshal ¶
func (m *V3WriteCapability) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3WriteCapability) XXX_Merge ¶
func (dst *V3WriteCapability) XXX_Merge(src proto.Message)
func (*V3WriteCapability) XXX_Size ¶
func (m *V3WriteCapability) XXX_Size() int
func (*V3WriteCapability) XXX_Unmarshal ¶
func (m *V3WriteCapability) XXX_Unmarshal(b []byte) error
type V3WriteData ¶
type V3WriteData struct {
// The action string for the write.
Action string `protobuf:"bytes,1,opt,name=action" json:"action,omitempty"`
// Additional data for the write action.
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
// A custom transaction that can be associated with the write.
Transaction string `protobuf:"bytes,3,opt,name=transaction" json:"transaction,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3WriteData is the data to write to a device.
func (*V3WriteData) Descriptor ¶
func (*V3WriteData) Descriptor() ([]byte, []int)
func (*V3WriteData) GetAction ¶
func (m *V3WriteData) GetAction() string
func (*V3WriteData) GetData ¶
func (m *V3WriteData) GetData() []byte
func (*V3WriteData) GetTransaction ¶
func (m *V3WriteData) GetTransaction() string
func (*V3WriteData) ProtoMessage ¶
func (*V3WriteData) ProtoMessage()
func (*V3WriteData) Reset ¶
func (m *V3WriteData) Reset()
func (*V3WriteData) String ¶
func (m *V3WriteData) String() string
func (*V3WriteData) XXX_DiscardUnknown ¶
func (m *V3WriteData) XXX_DiscardUnknown()
func (*V3WriteData) XXX_Marshal ¶
func (m *V3WriteData) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3WriteData) XXX_Merge ¶
func (dst *V3WriteData) XXX_Merge(src proto.Message)
func (*V3WriteData) XXX_Size ¶
func (m *V3WriteData) XXX_Size() int
func (*V3WriteData) XXX_Unmarshal ¶
func (m *V3WriteData) XXX_Unmarshal(b []byte) error
type V3WritePayload ¶
type V3WritePayload struct {
// The selector for the device to write to. This should resolve
// to a single device.
Selector *V3DeviceSelector `protobuf:"bytes,1,opt,name=selector" json:"selector,omitempty"`
// The data to write to the device.
Data []*V3WriteData `protobuf:"bytes,2,rep,name=data" json:"data,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3WritePayload the payload for a write which specifies the device to write to and the data to write.
func (*V3WritePayload) Descriptor ¶
func (*V3WritePayload) Descriptor() ([]byte, []int)
func (*V3WritePayload) GetData ¶
func (m *V3WritePayload) GetData() []*V3WriteData
func (*V3WritePayload) GetSelector ¶
func (m *V3WritePayload) GetSelector() *V3DeviceSelector
func (*V3WritePayload) ProtoMessage ¶
func (*V3WritePayload) ProtoMessage()
func (*V3WritePayload) Reset ¶
func (m *V3WritePayload) Reset()
func (*V3WritePayload) String ¶
func (m *V3WritePayload) String() string
func (*V3WritePayload) XXX_DiscardUnknown ¶
func (m *V3WritePayload) XXX_DiscardUnknown()
func (*V3WritePayload) XXX_Marshal ¶
func (m *V3WritePayload) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3WritePayload) XXX_Merge ¶
func (dst *V3WritePayload) XXX_Merge(src proto.Message)
func (*V3WritePayload) XXX_Size ¶
func (m *V3WritePayload) XXX_Size() int
func (*V3WritePayload) XXX_Unmarshal ¶
func (m *V3WritePayload) XXX_Unmarshal(b []byte) error
type V3WriteTransaction ¶
type V3WriteTransaction struct {
// The ID of the write transaction.
Id string `protobuf:"bytes,1,opt,name=id" json:"id,omitempty"`
// The GUID of the device written to.
Device string `protobuf:"bytes,2,opt,name=device" json:"device,omitempty"`
// The data that was written for the write transaction.
Context *V3WriteData `protobuf:"bytes,3,opt,name=context" json:"context,omitempty"`
// The timeout within which the transaction remains valid.
Timeout string `protobuf:"bytes,4,opt,name=timeout" json:"timeout,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
V3WriteTransaction contains information associating a write action with a transaction for asynchronous tracking.
func (*V3WriteTransaction) Descriptor ¶
func (*V3WriteTransaction) Descriptor() ([]byte, []int)
func (*V3WriteTransaction) GetContext ¶
func (m *V3WriteTransaction) GetContext() *V3WriteData
func (*V3WriteTransaction) GetDevice ¶
func (m *V3WriteTransaction) GetDevice() string
func (*V3WriteTransaction) GetId ¶
func (m *V3WriteTransaction) GetId() string
func (*V3WriteTransaction) GetTimeout ¶
func (m *V3WriteTransaction) GetTimeout() string
func (*V3WriteTransaction) ProtoMessage ¶
func (*V3WriteTransaction) ProtoMessage()
func (*V3WriteTransaction) Reset ¶
func (m *V3WriteTransaction) Reset()
func (*V3WriteTransaction) String ¶
func (m *V3WriteTransaction) String() string
func (*V3WriteTransaction) XXX_DiscardUnknown ¶
func (m *V3WriteTransaction) XXX_DiscardUnknown()
func (*V3WriteTransaction) XXX_Marshal ¶
func (m *V3WriteTransaction) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*V3WriteTransaction) XXX_Merge ¶
func (dst *V3WriteTransaction) XXX_Merge(src proto.Message)
func (*V3WriteTransaction) XXX_Size ¶
func (m *V3WriteTransaction) XXX_Size() int
func (*V3WriteTransaction) XXX_Unmarshal ¶
func (m *V3WriteTransaction) XXX_Unmarshal(b []byte) error
type WriteStatus ¶
type WriteStatus int32
WriteStatus are the statuses of a write as it is processed asynchronously.
const ( WriteStatus_PENDING WriteStatus = 0 WriteStatus_WRITING WriteStatus = 1 WriteStatus_DONE WriteStatus = 3 WriteStatus_ERROR WriteStatus = 4 )
func (WriteStatus) EnumDescriptor ¶
func (WriteStatus) EnumDescriptor() ([]byte, []int)
func (WriteStatus) String ¶
func (x WriteStatus) String() string